@@ -10,17 +10,13 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "base_host_data_source.h", "d4/d22/base__host__data__source_8h.html", "d4/d22/base__host__data__source_8h" ],
     [ "cache_host_data_source.h", "d8/d8f/cache__host__data__source_8h.html", "d8/d8f/cache__host__data__source_8h" ],
     [ "callout_handle_store.h", "dc/d16/callout__handle__store_8h.html", "dc/d16/callout__handle__store_8h" ],
-    [ "cb_ctl_dhcp.h", "d9/d64/cb__ctl__dhcp_8h.html", [
-      [ "isc::dhcp::CBControlDHCP< ConfigBackendMgrType >", "df/d82/classisc_1_1dhcp_1_1CBControlDHCP.html", "df/d82/classisc_1_1dhcp_1_1CBControlDHCP" ]
-    ] ],
+    [ "cb_ctl_dhcp.h", "d9/d64/cb__ctl__dhcp_8h.html", "d9/d64/cb__ctl__dhcp_8h" ],
     [ "cb_ctl_dhcp4.cc", "d6/d63/cb__ctl__dhcp4_8cc.html", null ],
     [ "cb_ctl_dhcp4.h", "d9/dc6/cb__ctl__dhcp4_8h.html", "d9/dc6/cb__ctl__dhcp4_8h" ],
     [ "cb_ctl_dhcp6.cc", "dc/dc3/cb__ctl__dhcp6_8cc.html", null ],
     [ "cb_ctl_dhcp6.h", "de/d98/cb__ctl__dhcp6_8h.html", "de/d98/cb__ctl__dhcp6_8h" ],
     [ "cfg_4o6.cc", "d4/d89/cfg__4o6_8cc.html", null ],
-    [ "cfg_4o6.h", "dd/d0a/cfg__4o6_8h.html", [
-      [ "isc::dhcp::Cfg4o6", "d6/dba/structisc_1_1dhcp_1_1Cfg4o6.html", "d6/dba/structisc_1_1dhcp_1_1Cfg4o6" ]
-    ] ],
+    [ "cfg_4o6.h", "dd/d0a/cfg__4o6_8h.html", "dd/d0a/cfg__4o6_8h" ],
     [ "cfg_consistency.cc", "d0/df3/cfg__consistency_8cc.html", null ],
     [ "cfg_consistency.h", "dd/d94/cfg__consistency_8h.html", "dd/d94/cfg__consistency_8h" ],
     [ "cfg_db_access.cc", "d0/d02/cfg__db__access_8cc.html", null ],
@@ -36,17 +32,13 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "cfg_hosts.cc", "d8/db3/cfg__hosts_8cc.html", null ],
     [ "cfg_hosts.h", "d1/d3b/cfg__hosts_8h.html", "d1/d3b/cfg__hosts_8h" ],
     [ "cfg_hosts_util.cc", "d6/db4/cfg__hosts__util_8cc.html", null ],
-    [ "cfg_hosts_util.h", "d2/dcb/cfg__hosts__util_8h.html", [
-      [ "isc::dhcp::CfgHostsList", "d9/d75/classisc_1_1dhcp_1_1CfgHostsList.html", "d9/d75/classisc_1_1dhcp_1_1CfgHostsList" ]
-    ] ],
+    [ "cfg_hosts_util.h", "d2/dcb/cfg__hosts__util_8h.html", "d2/dcb/cfg__hosts__util_8h" ],
     [ "cfg_iface.cc", "d7/dc1/cfg__iface_8cc.html", null ],
     [ "cfg_iface.h", "d9/d08/cfg__iface_8h.html", "d9/d08/cfg__iface_8h" ],
     [ "cfg_mac_source.cc", "d0/d37/cfg__mac__source_8cc.html", null ],
     [ "cfg_mac_source.h", "d9/d06/cfg__mac__source_8h.html", "d9/d06/cfg__mac__source_8h" ],
     [ "cfg_multi_threading.cc", "d8/d2b/cfg__multi__threading_8cc.html", null ],
-    [ "cfg_multi_threading.h", "d9/d9d/cfg__multi__threading_8h.html", [
-      [ "isc::dhcp::CfgMultiThreading", "d8/dfd/classisc_1_1dhcp_1_1CfgMultiThreading.html", null ]
-    ] ],
+    [ "cfg_multi_threading.h", "d9/d9d/cfg__multi__threading_8h.html", "d9/d9d/cfg__multi__threading_8h" ],
     [ "cfg_option.cc", "d0/d78/cfg__option_8cc.html", null ],
     [ "cfg_option.h", "de/d8f/cfg__option_8h.html", "de/d8f/cfg__option_8h" ],
     [ "cfg_option_def.cc", "d8/d29/cfg__option__def_8cc.html", null ],
@@ -60,59 +52,37 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "cfg_subnets6.cc", "d8/dc8/cfg__subnets6_8cc.html", null ],
     [ "cfg_subnets6.h", "d7/dbe/cfg__subnets6_8h.html", "d7/dbe/cfg__subnets6_8h" ],
     [ "cfgmgr.cc", "d8/d01/cfgmgr_8cc.html", null ],
-    [ "cfgmgr.h", "d3/d62/cfgmgr_8h.html", [
-      [ "isc::dhcp::CfgMgr", "da/d7f/classisc_1_1dhcp_1_1CfgMgr.html", "da/d7f/classisc_1_1dhcp_1_1CfgMgr" ],
-      [ "isc::dhcp::DuplicateListeningIface", "dc/d29/classisc_1_1dhcp_1_1DuplicateListeningIface.html", "dc/d29/classisc_1_1dhcp_1_1DuplicateListeningIface" ]
-    ] ],
+    [ "cfgmgr.h", "d3/d62/cfgmgr_8h.html", "d3/d62/cfgmgr_8h" ],
     [ "client_class_def.cc", "d9/d92/client__class__def_8cc.html", "d9/d92/client__class__def_8cc" ],
     [ "client_class_def.h", "dd/d60/client__class__def_8h.html", "dd/d60/client__class__def_8h" ],
     [ "config_backend_dhcp4.h", "d8/d7b/config__backend__dhcp4_8h.html", "d8/d7b/config__backend__dhcp4_8h" ],
     [ "config_backend_dhcp4_mgr.cc", "db/dd0/config__backend__dhcp4__mgr_8cc.html", null ],
-    [ "config_backend_dhcp4_mgr.h", "d8/d3c/config__backend__dhcp4__mgr_8h.html", [
-      [ "isc::dhcp::ConfigBackendDHCPv4Mgr", "d1/d6c/classisc_1_1dhcp_1_1ConfigBackendDHCPv4Mgr.html", null ]
-    ] ],
+    [ "config_backend_dhcp4_mgr.h", "d8/d3c/config__backend__dhcp4__mgr_8h.html", "d8/d3c/config__backend__dhcp4__mgr_8h" ],
     [ "config_backend_dhcp6.h", "d5/dee/config__backend__dhcp6_8h.html", "d5/dee/config__backend__dhcp6_8h" ],
     [ "config_backend_dhcp6_mgr.cc", "d4/dfb/config__backend__dhcp6__mgr_8cc.html", null ],
-    [ "config_backend_dhcp6_mgr.h", "d7/d23/config__backend__dhcp6__mgr_8h.html", [
-      [ "isc::dhcp::ConfigBackendDHCPv6Mgr", "d2/def/classisc_1_1dhcp_1_1ConfigBackendDHCPv6Mgr.html", null ]
-    ] ],
+    [ "config_backend_dhcp6_mgr.h", "d7/d23/config__backend__dhcp6__mgr_8h.html", "d7/d23/config__backend__dhcp6__mgr_8h" ],
     [ "config_backend_pool_dhcp4.cc", "dd/d2d/config__backend__pool__dhcp4_8cc.html", null ],
-    [ "config_backend_pool_dhcp4.h", "db/db8/config__backend__pool__dhcp4_8h.html", [
-      [ "isc::dhcp::ConfigBackendPoolDHCPv4", "d6/df9/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv4.html", "d6/df9/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv4" ]
-    ] ],
+    [ "config_backend_pool_dhcp4.h", "db/db8/config__backend__pool__dhcp4_8h.html", "db/db8/config__backend__pool__dhcp4_8h" ],
     [ "config_backend_pool_dhcp6.cc", "dd/d7d/config__backend__pool__dhcp6_8cc.html", null ],
-    [ "config_backend_pool_dhcp6.h", "d1/d4c/config__backend__pool__dhcp6_8h.html", [
-      [ "isc::dhcp::ConfigBackendPoolDHCPv6", "d8/dfb/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv6.html", "d8/dfb/classisc_1_1dhcp_1_1ConfigBackendPoolDHCPv6" ]
-    ] ],
+    [ "config_backend_pool_dhcp6.h", "d1/d4c/config__backend__pool__dhcp6_8h.html", "d1/d4c/config__backend__pool__dhcp6_8h" ],
     [ "csv_lease_file4.cc", "dc/db8/csv__lease__file4_8cc.html", null ],
-    [ "csv_lease_file4.h", "dd/dde/csv__lease__file4_8h.html", [
-      [ "isc::dhcp::CSVLeaseFile4", "d4/dac/classisc_1_1dhcp_1_1CSVLeaseFile4.html", "d4/dac/classisc_1_1dhcp_1_1CSVLeaseFile4" ]
-    ] ],
+    [ "csv_lease_file4.h", "dd/dde/csv__lease__file4_8h.html", "dd/dde/csv__lease__file4_8h" ],
     [ "csv_lease_file6.cc", "d2/dfe/csv__lease__file6_8cc.html", null ],
-    [ "csv_lease_file6.h", "df/dbf/csv__lease__file6_8h.html", [
-      [ "isc::dhcp::CSVLeaseFile6", "d6/d82/classisc_1_1dhcp_1_1CSVLeaseFile6.html", "d6/d82/classisc_1_1dhcp_1_1CSVLeaseFile6" ]
-    ] ],
+    [ "csv_lease_file6.h", "df/dbf/csv__lease__file6_8h.html", "df/dbf/csv__lease__file6_8h" ],
     [ "d2_client_cfg.cc", "de/da0/d2__client__cfg_8cc.html", "de/da0/d2__client__cfg_8cc" ],
     [ "d2_client_cfg.h", "d8/ded/d2__client__cfg_8h.html", "d8/ded/d2__client__cfg_8h" ],
     [ "d2_client_mgr.cc", "d4/dce/d2__client__mgr_8cc.html", null ],
     [ "d2_client_mgr.h", "d8/d9a/d2__client__mgr_8h.html", "d8/d9a/d2__client__mgr_8h" ],
     [ "db_type.h", "d1/d14/db__type_8h.html", "d1/d14/db__type_8h" ],
     [ "dhcp4o6_ipc.cc", "d8/dbf/dhcp4o6__ipc_8cc.html", null ],
-    [ "dhcp4o6_ipc.h", "de/db6/dhcp4o6__ipc_8h.html", [
-      [ "isc::dhcp::Dhcp4o6IpcBase", "d7/d39/classisc_1_1dhcp_1_1Dhcp4o6IpcBase.html", "d7/d39/classisc_1_1dhcp_1_1Dhcp4o6IpcBase" ],
-      [ "isc::dhcp::Dhcp4o6IpcError", "db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError.html", "db/d85/classisc_1_1dhcp_1_1Dhcp4o6IpcError" ]
-    ] ],
-    [ "dhcpsrv_exceptions.h", "d4/d05/dhcpsrv__exceptions_8h.html", [
-      [ "isc::dhcp::NoSuchLease", "de/da0/classisc_1_1dhcp_1_1NoSuchLease.html", "de/da0/classisc_1_1dhcp_1_1NoSuchLease" ]
-    ] ],
+    [ "dhcp4o6_ipc.h", "de/db6/dhcp4o6__ipc_8h.html", "de/db6/dhcp4o6__ipc_8h" ],
+    [ "dhcpsrv_exceptions.h", "d4/d05/dhcpsrv__exceptions_8h.html", "d4/d05/dhcpsrv__exceptions_8h" ],
     [ "dhcpsrv_log.cc", "d6/d01/dhcpsrv__log_8cc.html", "d6/d01/dhcpsrv__log_8cc" ],
     [ "dhcpsrv_log.h", "d5/d5a/dhcpsrv__log_8h.html", null ],
     [ "dhcpsrv_messages.cc", "d1/d9a/dhcpsrv__messages_8cc.html", "d1/d9a/dhcpsrv__messages_8cc" ],
     [ "dhcpsrv_messages.h", "d9/d96/dhcpsrv__messages_8h.html", null ],
     [ "free_lease_queue.cc", "de/d48/free__lease__queue_8cc.html", null ],
-    [ "free_lease_queue.h", "de/df3/free__lease__queue_8h.html", [
-      [ "isc::dhcp::FreeLeaseQueue", "d4/d3c/classisc_1_1dhcp_1_1FreeLeaseQueue.html", "d4/d3c/classisc_1_1dhcp_1_1FreeLeaseQueue" ]
-    ] ],
+    [ "free_lease_queue.h", "de/df3/free__lease__queue_8h.html", "de/df3/free__lease__queue_8h" ],
     [ "fuzz.cc", "d8/d43/fuzz_8cc.html", null ],
     [ "fuzz.h", "d6/d98/fuzz_8h.html", null ],
     [ "fuzz_log.cc", "d9/d25/fuzz__log_8cc.html", "d9/d25/fuzz__log_8cc" ],
@@ -123,96 +93,51 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "host.h", "df/ded/host_8h.html", "df/ded/host_8h" ],
     [ "host_container.h", "d0/d42/host__container_8h.html", "d0/d42/host__container_8h" ],
     [ "host_data_source_factory.cc", "d3/da7/host__data__source__factory_8cc.html", null ],
-    [ "host_data_source_factory.h", "d9/da2/host__data__source__factory_8h.html", [
-      [ "isc::dhcp::HostDataSourceFactory", "dd/de3/classisc_1_1dhcp_1_1HostDataSourceFactory.html", "dd/de3/classisc_1_1dhcp_1_1HostDataSourceFactory" ],
-      [ "isc::dhcp::NoHostDataSourceManager", "d1/da7/classisc_1_1dhcp_1_1NoHostDataSourceManager.html", "d1/da7/classisc_1_1dhcp_1_1NoHostDataSourceManager" ]
-    ] ],
+    [ "host_data_source_factory.h", "d9/da2/host__data__source__factory_8h.html", "d9/da2/host__data__source__factory_8h" ],
     [ "host_mgr.cc", "df/d84/host__mgr_8cc.html", null ],
-    [ "host_mgr.h", "d8/d2c/host__mgr_8h.html", [
-      [ "isc::dhcp::HostMgr", "d9/d9a/classisc_1_1dhcp_1_1HostMgr.html", "d9/d9a/classisc_1_1dhcp_1_1HostMgr" ]
-    ] ],
+    [ "host_mgr.h", "d8/d2c/host__mgr_8h.html", "d8/d2c/host__mgr_8h" ],
     [ "hosts_log.cc", "d4/d31/hosts__log_8cc.html", "d4/d31/hosts__log_8cc" ],
     [ "hosts_log.h", "d7/d8f/hosts__log_8h.html", null ],
     [ "hosts_messages.cc", "de/d3f/hosts__messages_8cc.html", "de/d3f/hosts__messages_8cc" ],
     [ "hosts_messages.h", "d2/d24/hosts__messages_8h.html", null ],
     [ "ip_range.cc", "dc/d4c/ip__range_8cc.html", null ],
-    [ "ip_range.h", "d9/d85/ip__range_8h.html", [
-      [ "isc::dhcp::AddressRange", "d3/dc4/structisc_1_1dhcp_1_1AddressRange.html", "d3/dc4/structisc_1_1dhcp_1_1AddressRange" ],
-      [ "isc::dhcp::PrefixRange", "d2/d05/structisc_1_1dhcp_1_1PrefixRange.html", "d2/d05/structisc_1_1dhcp_1_1PrefixRange" ]
-    ] ],
+    [ "ip_range.h", "d9/d85/ip__range_8h.html", "d9/d85/ip__range_8h" ],
     [ "ip_range_permutation.cc", "d8/dda/ip__range__permutation_8cc.html", null ],
     [ "ip_range_permutation.h", "d8/da6/ip__range__permutation_8h.html", "d8/da6/ip__range__permutation_8h" ],
-    [ "key_from_key.h", "d9/ddf/key__from__key_8h.html", [
-      [ "isc::dhcp::KeyFromKeyExtractor< KeyExtractor1, KeyExtractor2 >", "d3/d73/classisc_1_1dhcp_1_1KeyFromKeyExtractor.html", "d3/d73/classisc_1_1dhcp_1_1KeyFromKeyExtractor" ]
-    ] ],
+    [ "key_from_key.h", "d9/ddf/key__from__key_8h.html", "d9/ddf/key__from__key_8h" ],
     [ "lease.cc", "d3/d86/lease_8cc.html", "d3/d86/lease_8cc" ],
     [ "lease.h", "d6/da0/lease_8h.html", "d6/da0/lease_8h" ],
-    [ "lease_file_loader.h", "d1/dc0/lease__file__loader_8h.html", [
-      [ "isc::dhcp::LeaseFileLoader", "da/df1/classisc_1_1dhcp_1_1LeaseFileLoader.html", null ]
-    ] ],
-    [ "lease_file_stats.h", "d4/d82/lease__file__stats_8h.html", [
-      [ "isc::dhcp::LeaseFileStats", "db/d56/classisc_1_1dhcp_1_1LeaseFileStats.html", "db/d56/classisc_1_1dhcp_1_1LeaseFileStats" ]
-    ] ],
+    [ "lease_file_loader.h", "d1/dc0/lease__file__loader_8h.html", "d1/dc0/lease__file__loader_8h" ],
+    [ "lease_file_stats.h", "d4/d82/lease__file__stats_8h.html", "d4/d82/lease__file__stats_8h" ],
     [ "lease_mgr.cc", "d3/d29/lease__mgr_8cc.html", null ],
     [ "lease_mgr.h", "dc/dc3/lease__mgr_8h.html", "dc/dc3/lease__mgr_8h" ],
     [ "lease_mgr_factory.cc", "d6/d90/lease__mgr__factory_8cc.html", null ],
-    [ "lease_mgr_factory.h", "df/d01/lease__mgr__factory_8h.html", [
-      [ "isc::dhcp::LeaseMgrFactory", "d3/dc6/classisc_1_1dhcp_1_1LeaseMgrFactory.html", null ],
-      [ "isc::dhcp::NoLeaseManager", "d3/d76/classisc_1_1dhcp_1_1NoLeaseManager.html", "d3/d76/classisc_1_1dhcp_1_1NoLeaseManager" ]
-    ] ],
+    [ "lease_mgr_factory.h", "df/d01/lease__mgr__factory_8h.html", "df/d01/lease__mgr__factory_8h" ],
     [ "memfile_lease_limits.cc", "db/d2b/memfile__lease__limits_8cc.html", null ],
-    [ "memfile_lease_limits.h", "db/d6e/memfile__lease__limits_8h.html", [
-      [ "isc::dhcp::ClassLeaseCounter", "d6/d50/classisc_1_1dhcp_1_1ClassLeaseCounter.html", "d6/d50/classisc_1_1dhcp_1_1ClassLeaseCounter" ]
-    ] ],
-    [ "memfile_lease_mgr.cc", "db/dd3/memfile__lease__mgr_8cc.html", [
-      [ "isc::dhcp::LFCSetup", "d7/dae/classisc_1_1dhcp_1_1LFCSetup.html", "d7/dae/classisc_1_1dhcp_1_1LFCSetup" ],
-      [ "isc::dhcp::MemfileLeaseStatsQuery", "d2/d28/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery.html", "d2/d28/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery" ],
-      [ "isc::dhcp::MemfileLeaseStatsQuery4", "db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4.html", "db/d7e/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery4" ],
-      [ "isc::dhcp::MemfileLeaseStatsQuery6", "d6/df2/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery6.html", "d6/df2/classisc_1_1dhcp_1_1MemfileLeaseStatsQuery6" ]
-    ] ],
-    [ "memfile_lease_mgr.h", "d7/d6b/memfile__lease__mgr_8h.html", [
-      [ "isc::dhcp::Memfile_LeaseMgr", "dc/dec/classisc_1_1dhcp_1_1Memfile__LeaseMgr.html", "dc/dec/classisc_1_1dhcp_1_1Memfile__LeaseMgr" ]
-    ] ],
+    [ "memfile_lease_limits.h", "db/d6e/memfile__lease__limits_8h.html", "db/d6e/memfile__lease__limits_8h" ],
+    [ "memfile_lease_mgr.cc", "db/dd3/memfile__lease__mgr_8cc.html", "db/dd3/memfile__lease__mgr_8cc" ],
+    [ "memfile_lease_mgr.h", "d7/d6b/memfile__lease__mgr_8h.html", "d7/d6b/memfile__lease__mgr_8h" ],
     [ "memfile_lease_storage.h", "df/db1/memfile__lease__storage_8h.html", "df/db1/memfile__lease__storage_8h" ],
     [ "mysql_host_data_source.cc", "d6/d26/mysql__host__data__source_8cc.html", "d6/d26/mysql__host__data__source_8cc" ],
     [ "mysql_host_data_source.h", "d9/dbb/mysql__host__data__source_8h.html", "d9/dbb/mysql__host__data__source_8h" ],
-    [ "mysql_lease_mgr.cc", "d2/d0a/mysql__lease__mgr_8cc.html", [
-      [ "isc::dhcp::MySqlLease4Exchange", "d9/d5d/classisc_1_1dhcp_1_1MySqlLease4Exchange.html", "d9/d5d/classisc_1_1dhcp_1_1MySqlLease4Exchange" ],
-      [ "isc::dhcp::MySqlLease6Exchange", "d6/df3/classisc_1_1dhcp_1_1MySqlLease6Exchange.html", "d6/df3/classisc_1_1dhcp_1_1MySqlLease6Exchange" ],
-      [ "isc::dhcp::MySqlLeaseExchange", "dc/d5e/classisc_1_1dhcp_1_1MySqlLeaseExchange.html", null ],
-      [ "isc::dhcp::MySqlLeaseStatsQuery", "de/dfb/classisc_1_1dhcp_1_1MySqlLeaseStatsQuery.html", "de/dfb/classisc_1_1dhcp_1_1MySqlLeaseStatsQuery" ]
-    ] ],
+    [ "mysql_lease_mgr.cc", "d2/d0a/mysql__lease__mgr_8cc.html", "d2/d0a/mysql__lease__mgr_8cc" ],
     [ "mysql_lease_mgr.h", "d7/d2f/mysql__lease__mgr_8h.html", "d7/d2f/mysql__lease__mgr_8h" ],
     [ "ncr_generator.cc", "d0/d6d/ncr__generator_8cc.html", "d0/d6d/ncr__generator_8cc" ],
     [ "ncr_generator.h", "d9/de6/ncr__generator_8h.html", "d9/de6/ncr__generator_8h" ],
     [ "network.cc", "d7/d9e/network_8cc.html", null ],
     [ "network.h", "d9/d94/network_8h.html", "d9/d94/network_8h" ],
-    [ "network_state.cc", "d0/dac/network__state_8cc.html", [
-      [ "isc::dhcp::NetworkStateImpl", "da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html", "da/d52/classisc_1_1dhcp_1_1NetworkStateImpl" ]
-    ] ],
+    [ "network_state.cc", "d0/dac/network__state_8cc.html", "d0/dac/network__state_8cc" ],
     [ "network_state.h", "d9/dfc/network__state_8h.html", "d9/dfc/network__state_8h" ],
     [ "pgsql_host_data_source.cc", "d8/d1f/pgsql__host__data__source_8cc.html", "d8/d1f/pgsql__host__data__source_8cc" ],
     [ "pgsql_host_data_source.h", "d1/db5/pgsql__host__data__source_8h.html", "d1/db5/pgsql__host__data__source_8h" ],
-    [ "pgsql_lease_mgr.cc", "de/d03/pgsql__lease__mgr_8cc.html", [
-      [ "isc::dhcp::PgSqlLease4Exchange", "dc/d13/classisc_1_1dhcp_1_1PgSqlLease4Exchange.html", "dc/d13/classisc_1_1dhcp_1_1PgSqlLease4Exchange" ],
-      [ "isc::dhcp::PgSqlLease6Exchange", "d9/dd3/classisc_1_1dhcp_1_1PgSqlLease6Exchange.html", "d9/dd3/classisc_1_1dhcp_1_1PgSqlLease6Exchange" ],
-      [ "isc::dhcp::PgSqlLeaseExchange", "d4/d9f/classisc_1_1dhcp_1_1PgSqlLeaseExchange.html", "d4/d9f/classisc_1_1dhcp_1_1PgSqlLeaseExchange" ],
-      [ "isc::dhcp::PgSqlLeaseStatsQuery", "da/d71/classisc_1_1dhcp_1_1PgSqlLeaseStatsQuery.html", "da/d71/classisc_1_1dhcp_1_1PgSqlLeaseStatsQuery" ],
-      [ "isc::dhcp::PgSqlLease6Exchange::Uiaid", "da/d20/unionisc_1_1dhcp_1_1PgSqlLease6Exchange_1_1Uiaid.html", "da/d20/unionisc_1_1dhcp_1_1PgSqlLease6Exchange_1_1Uiaid" ]
-    ] ],
+    [ "pgsql_lease_mgr.cc", "de/d03/pgsql__lease__mgr_8cc.html", "de/d03/pgsql__lease__mgr_8cc" ],
     [ "pgsql_lease_mgr.h", "da/dfc/pgsql__lease__mgr_8h.html", "da/dfc/pgsql__lease__mgr_8h" ],
     [ "pool.cc", "d4/de9/pool_8cc.html", null ],
     [ "pool.h", "db/db7/pool_8h.html", "db/db7/pool_8h" ],
     [ "resource_handler.cc", "d4/d67/resource__handler_8cc.html", null ],
-    [ "resource_handler.h", "df/d68/resource__handler_8h.html", [
-      [ "isc::dhcp::ResourceBusy", "d6/de1/classisc_1_1dhcp_1_1ResourceBusy.html", "d6/de1/classisc_1_1dhcp_1_1ResourceBusy" ],
-      [ "isc::dhcp::ResourceHandler", "d3/d49/classisc_1_1dhcp_1_1ResourceHandler.html", "d3/d49/classisc_1_1dhcp_1_1ResourceHandler" ],
-      [ "isc::dhcp::ResourceHandler4", "da/d8b/classisc_1_1dhcp_1_1ResourceHandler4.html", "da/d8b/classisc_1_1dhcp_1_1ResourceHandler4" ]
-    ] ],
+    [ "resource_handler.h", "df/d68/resource__handler_8h.html", "df/d68/resource__handler_8h" ],
     [ "sanity_checker.cc", "d4/d0c/sanity__checker_8cc.html", null ],
-    [ "sanity_checker.h", "de/dc7/sanity__checker_8h.html", [
-      [ "isc::dhcp::SanityChecker", "db/d23/classisc_1_1dhcp_1_1SanityChecker.html", "db/d23/classisc_1_1dhcp_1_1SanityChecker" ]
-    ] ],
+    [ "sanity_checker.h", "de/dc7/sanity__checker_8h.html", "de/dc7/sanity__checker_8h" ],
     [ "shared_network.cc", "df/da6/shared__network_8cc.html", null ],
     [ "shared_network.h", "d6/d55/shared__network_8h.html", "d6/d55/shared__network_8h" ],
     [ "srv_config.cc", "d3/d7b/srv__config_8cc.html", null ],
@@ -220,15 +145,9 @@ var dir_b1053a8cf5074fcb3b0c4506b0d7724e =
     [ "subnet.cc", "d6/d23/subnet_8cc.html", null ],
     [ "subnet.h", "d5/d04/subnet_8h.html", "d5/d04/subnet_8h" ],
     [ "subnet_id.h", "d7/da2/subnet__id_8h.html", "d7/da2/subnet__id_8h" ],
-    [ "subnet_selector.h", "da/d8a/subnet__selector_8h.html", [
-      [ "isc::dhcp::SubnetSelector", "d6/d01/structisc_1_1dhcp_1_1SubnetSelector.html", "d6/d01/structisc_1_1dhcp_1_1SubnetSelector" ]
-    ] ],
+    [ "subnet_selector.h", "da/d8a/subnet__selector_8h.html", "da/d8a/subnet__selector_8h" ],
     [ "timer_mgr.cc", "d4/d12/timer__mgr_8cc.html", "d4/d12/timer__mgr_8cc" ],
     [ "timer_mgr.h", "d5/d3c/timer__mgr_8h.html", "d5/d3c/timer__mgr_8h" ],
-    [ "utils.h", "d5/d60/utils_8h.html", [
-      [ "isc::dhcp::RFCViolation", "d8/de5/classisc_1_1dhcp_1_1RFCViolation.html", "d8/de5/classisc_1_1dhcp_1_1RFCViolation" ]
-    ] ],
-    [ "writable_host_data_source.h", "d4/d10/writable__host__data__source_8h.html", [
-      [ "isc::dhcp::WritableHostDataSource", "d1/d06/classisc_1_1dhcp_1_1WritableHostDataSource.html", "d1/d06/classisc_1_1dhcp_1_1WritableHostDataSource" ]
-    ] ]
+    [ "utils.h", "d5/d60/utils_8h.html", "d5/d60/utils_8h" ],
+    [ "writable_host_data_source.h", "d4/d10/writable__host__data__source_8h.html", "d4/d10/writable__host__data__source_8h" ]
 ];
\ No newline at end of file
