@@ -5,7 +5,5 @@ var dir_cc3c32580a7bbd01de8c4133ec67aa1e =
     [ "observation.cc", "de/df2/observation_8cc.html", null ],
     [ "observation.h", "d3/dab/observation_8h.html", "d3/dab/observation_8h" ],
     [ "lib/stats/stats_mgr.cc", "d1/d82/lib_2stats_2stats__mgr_8cc.html", null ],
-    [ "lib/stats/stats_mgr.h", "dd/df0/lib_2stats_2stats__mgr_8h.html", [
-      [ "isc::stats::StatsMgr", "d3/de5/classisc_1_1stats_1_1StatsMgr.html", "d3/de5/classisc_1_1stats_1_1StatsMgr" ]
-    ] ]
+    [ "lib/stats/stats_mgr.h", "dd/df0/lib_2stats_2stats__mgr_8h.html", "dd/df0/lib_2stats_2stats__mgr_8h" ]
 ];
\ No newline at end of file
